{{
'-------------------------------------------------------------------------------
'
' Catalina_Common - Common definitions for the Catalina LMM and XMM Kernels and
'                   targets.
' 
'                   This file is where the PIN Definitions used by various
'                   Propeller devices are stored. It also contains routines
'                   for setting up and using the common registry.
'
'
' Version 1.0 - Initial version - by Ross Higson
' Version 1.1 - Added Hybrid pin and clock details
'             - Added SD Loader and Float Xfer details.
' Version 1.3 - Added Morpheus support
'             - Tidied up and combined sections (now one section per platform)
' Version 1.4 - Added DracBlade support
' Version 1.5 - Added RamBlade support
'               Added BlackCat support
' Version 1.6 - Added correct LMM_1_OFF for XMM Kernels.
'               Moved DEBUG_VECTORS
' Version 2.6 - Added separate pin defs for Payload to use
'
' Version 2.8 - Added LMM_DUM (Dummy Plugin)
'               Added RESERVE_COG support
'               Added ASC support (Arduino Shield Compatible)
' VErsion 2.9 - Added C3 support
' Version 3.0 - New Registry layout
'               Added C3 FLASH support
'               Added Cache support (compatible with jazzed's spisram_cache)
'
'------------------------------------------------------------------------------
'
'    Copyright 2009 Ross Higson
'
'    This file is part of the Catalina Target Package.
'
'    The Catalina Target Package is free software: you can redistribute 
'    it and/or modify it under the terms of the GNU Lesser General Public 
'    License as published by the Free Software Foundation, either version 
'    3 of the License, or (at your option) any later version.
'
'    The Catalina Target Package is distributed in the hope that it will
'    be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
'    of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  
'    See the GNU Lesser General Public License for more details.
'
'    You should have received a copy of the GNU Lesser General Public 
'    License along with the Catalina Target Package.  If not, see 
'    <http://www.gnu.org/licenses/>.
'
'------------------------------------------------------------------------------
}}
CON
'
' Pin groups or base pins for mouse, keyboard and screen. Change these to suit
' your Propeller platform. Add more definitions here if required for additional
' platforms, drivers and plugins.
'
' Clock modes and crystal frequency must be set in the top level object, but
' those objects just use the definitions here. Change them as required to suit
' your Propeller platform.
'

' Caching options - allow CACHED_2K, CACHED_4K, CACHED_8K or just CACHED
' (note - we include this here in case Constants.inc is not included)
' 
#ifdef CACHED_1K
#ifndef CACHED
#define CACHED
#endif
#elseifdef CACHED_2K
#ifndef CACHED
#define CACHED
#endif
#elseifdef CACHED_4K
#ifndef CACHED
#define CACHED
#endif
#elseifdef CACHED_8K
#ifndef CACHED
#define CACHED
#endif
#endif
'
#ifdef HYDRA
'===============================================================================
'
' Hydra General definitions:
'
'===============================================================================
KBD_PIN    = 13                 ' BASE PIN  (Hydra)
MOUSE_PIN  = 2                  ' PIN GROUP (Hydra)
TV_PIN     = 24                 ' BASE PIN  (Hydra)
VGA_PIN    = 16                 ' BASE PIN  (Hydra)
SD_DO_PIN  = 16                 ' (Hydra) - note shared with VGA
SD_CLK_PIN = 17                 ' (Hydra) - note shared with VGA 
SD_DI_PIN  = 18                 ' (Hydra) - note shared with VGA
SD_CS_PIN  = 19                 ' (Hydra) - note shared with VGA
I2C_PIN    = 28                 ' I2C Boot EEPROM SCL Pin
I2C_DEV    = $A0                ' I2C Boot EEPROM Device Address
SI_PIN     = 31                 ' PIN (Hydra)
SO_PIN     = 30                 ' PIN (Hydra)
'
' Hydra Clock definitions:
' 
CLOCKMODE = xtal2 + pll8x       ' (Hydra)
XTALFREQ  = 10_000_000          ' (Hydra)
CLOCKFREQ = 80_000_000          ' (Hydra) Nominal clock frequency (required by some drivers)
'
' Hydra Loader and InterProp Comms definitions:
'
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms and serial loading                
SIO_LOAD_MODE = %0000           ' Hydra has only one CPU - this is for serial loading
SIO_COMM_MODE = %0000           ' Hydra has only one CPU - this is for serial loading
TX_PIN        = -1              ' Hydra has only one CPU
RX_PIN        = -1              ' Hydra has only one CPU
'
' Hydra XMM Base Address:
'
XMM_BASE_ADDRESS = $0000_0000   ' XMM adddressing from 0
'
' Hydra SPI Base Address:
'
SPI_RW_BASE_ADDRESS  = -1       ' Hydra has no SPI
SPI_RO_BASE_ADDRESS  = -1       ' Hydra has no SPI
'
' Hydra Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' Hydra BlackCat debug pins (mouse pins) - can be used for LMM or XMM but requires special cable
'
BLACKCAT_RXPIN = 9              ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = 10             ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0010          ' SIO must invert Tx on Hydra when using mouse port
{
'
' Hydra BlackCat debug pins (SI/SO pins) - can only be used for LMM, but uses normal serial cable
'
BLACKCAT_RXPIN = SI_PIN         ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = SO_PIN         ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
}
'
' Hydra Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' sarted in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve another cog 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by
' an application - it simply is not restarted during the load process 
' (otherwise its values will be lost). Finally, note that this logic
' is replicated for each platform even though it is currently the same
' on all - there may one day be a platform that needs to reserve some
' additional cogs.
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog

#ifdef RESERVE_COG
RESERVED_COG = 6                ' Cog 6 is reserved
LAST_COG     = 4                ' Last cog to be restarted is 4
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 5                ' Last cog to be restarted is 5
#endif

#else

CACHE_COG = -1                  ' XMM Cache driver not loaded

#ifdef RESERVE_COG
RESERVED_COG = 7                ' Cog 6 is reserved
LAST_COG     = 5                ' Last cog to be restarted is 5
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 6                ' Last cog to be restarted is 6
#endif

#endif 


#elseifdef HYBRID
'===============================================================================
'
' Hybrid General definitions:
'
'===============================================================================
KBD_PIN    = 12                 ' BASE PIN  (Hybrid)
MOUSE_PIN  = 14                 ' BASE PIN  (Hybrid)
TV_PIN     = 24                 ' BASE PIN  (Hybrid)
VGA_PIN    = -1                 ' Hybrid has no VGA 
SD_DO_PIN  = 8                  ' (Hybrid)
SD_CLK_PIN = 9                  ' (Hybrid) 
SD_DI_PIN  = 10                 ' (Hybrid)
SD_CS_PIN  = 11                 ' (Hybrid)
I2C_PIN    = 28                 ' I2C Boot EEPROM SCL Pin
I2C_DEV    = $A0                ' I2C Boot EEPROM Device Address
SI_PIN     = 31                 ' PIN (Hybrid)
SO_PIN     = 30                 ' PIN (Hybrid)
'
' Hybrid Clock definitions:
' 
CLOCKMODE = xtal1 + pll16x      ' (Hybrid)
XTALFREQ  = 6_000_000           ' (Hybrid)
CLOCKFREQ = 96_000_000          ' (Hybrid) Nominal clock frequency (required by some drivers)
'
' Hybrid Loader and InterProp Comms definitions:
'
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms and serial loading               
SIO_LOAD_MODE = %0000           ' Hybrid has only one CPU - this is for serial loading
SIO_COMM_MODE = %0000           ' Hybrid has only one CPU - this is for serial loading
TX_PIN        = -1              ' Hybrid has only one CPU
RX_PIN        = -1              ' Hybrid has only one CPU
' Hybrid XMM Base Address:
'
XMM_BASE_ADDRESS = $0000_0000   ' XMM adddressing from 0
'
' Hybrid SPI Base Address:
'
SPI_RW_BASE_ADDRESS  = -1       ' Hybrid has no SPI
SPI_RO_BASE_ADDRESS  = -1       ' Hybrid has no SPI
'
' Hybrid Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' Hybrid BlackCat debug pins (mouse pins) - can be used for LMM or XMM but requires special cable
'
BLACKCAT_RXPIN = 14             ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = 15             ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
{
'
' Hybrid BlackCat debug pins (SI/SO pins) - can only be used for LMM, but uses normal serial cable
'
BLACKCAT_RXPIN = SI_PIN         ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = SO_PIN         ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
}
'
' Hybrid Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' sarted in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve another cog 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by
' an application - it simply is not restarted during the load process 
' (otherwise its values will be lost). Finally, note that this logic
' is replicated for each platform even though it is currently the same
' on all - there may one day be a platform that needs to reserve some
' additional cogs.
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog

#ifdef RESERVE_COG
RESERVED_COG = 6                ' Cog 6 is reserved
LAST_COG     = 4                ' Last cog to be restarted is 4
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 5                ' Last cog to be restarted is 5
#endif

#else

CACHE_COG = -1                  ' XMM Cache driver not loaded

#ifdef RESERVE_COG
RESERVED_COG = 7                ' Cog 6 is reserved
LAST_COG     = 5                ' Last cog to be restarted is 5
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 6                ' Last cog to be restarted is 6
#endif

#endif 



#elseifdef C3                  
'===============================================================================
'
' C3 General definitions:
'
'===============================================================================
KBD_PIN    = 26                 ' BASE PIN  (C3) - NOTE SHARED WITH MOUSE
MOUSE_PIN  = 26                 ' BASE PIN  (C3) - NOTE SHARED WITH KBD
TV_PIN     = 12                 ' BASE PIN  (C3)
VGA_PIN    = 16                 ' BASE PIN  (C3)  
SD_DO_PIN  = 10                 ' PIN (C3)
SD_CLK_PIN = 11                 ' PIN (C3)
SD_DI_PIN  = 9                  ' PIN (C3)
SD_CS_CLK  = 8                  ' REQUIRES SPI SELECT LOGIC
SD_CS_CLR  = 25                 ' REQUIRES SPI SELECT LOGIC
I2C_PIN    = 28                 ' I2C Boot EEPROM SCL Pin
I2C_DEV    = $A0                ' I2C Boot EEPROM Device Address
SI_PIN     = 31                 ' PIN (C3)
SO_PIN     = 30                 ' PIN (C3)
'
VGA_ENABLE = 15                 ' PIN (C3)
'
' C3 SPI RAM Support 
'
SPI_SO      = 10                ' PIN (C3)
SPI_SI      = 9                 ' PIN (C3)
SPI_CLK     = 11                ' PIN (C3)
SPI_CS_CLR  = 25                ' REQUIRES SPI SELECT LOGIC
SPI_CS_CLK  = 8                 ' REQUIRES SPI SELECT LOGIC
'
' C3 Clock Definitions:
'
CLOCKMODE = xtal1 + pll16x      ' (C3)
XTALFREQ  = 5_000_000           ' (C3)
CLOCKFREQ = 80_000_000          ' (C3) Nominal clock frequency (required by some drivers)
'
' C3 InterProp comms definitions:
'
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms                 
SIO_LOAD_MODE = %0000           ' SIO Mode used by targets during load (loader uses SIO_COMM_MODE)
SIO_COMM_MODE = %0000           ' SIO Mode used by clients and servers for InteProp Comms

TX_PIN     = -1                 ' C3 has only one CPU
RX_PIN     = -1                 ' C3 has only one CPU
'
' C3 XMM Base Address. Catalina currently requires one contiguous block of XMM RAM:
'
XMM_BASE_ADDRESS = $0000_0000   ' XMM adddressing from 0
'
' C3 SPI Base Address:
'
SPI_RW_BASE_ADDRESS = $0000_8000 ' SPI Read-Write Base address
SPI_RO_BASE_ADDRESS = $0001_8000 ' SPI Read-Only Base address
'
' C3 Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' C3 BlackCat debug pins (SI/SO pins)
'
BLACKCAT_RXPIN = SI_PIN         ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = SO_PIN         ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
'
' C3 Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' sarted in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve another cog 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by
' an application - it simply is not restarted during the load process 
' (otherwise its values will be lost). Finally, note that this logic
' is replicated for each platform even though it is currently the same
' on all - there may one day be a platform that needs to reserve some
' additional cogs.
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog

#ifdef RESERVE_COG
RESERVED_COG = 6                ' Cog 6 is reserved
LAST_COG     = 4                ' Last cog to be restarted is 4
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 5                ' Last cog to be restarted is 5
#endif

#else

CACHE_COG = -1                  ' XMM Cache driver not loaded

#ifdef RESERVE_COG
RESERVED_COG = 7                ' Cog 6 is reserved
LAST_COG     = 5                ' Last cog to be restarted is 5
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 6                ' Last cog to be restarted is 6
#endif

#endif 


#elseifdef TRIBLADEPROP
'===============================================================================
'
' TriBladeProp CPU #1 General definitions:
'
'===============================================================================
' Note that there are two main ways to configure CPU #1 - for VGA or for TV.
' The keyboard and mouse can be configured to use two different sets of pins, 
' but to use XMM they MUST be configured to use pins 8 - 11. The VGA output 
' cannot be used at the same time as the XMM RAM, so there are therefore two 
' different sets of definitions given below. 
' The first assumes no XMM, VGA display, and mouse and keyboard on pins 24 - 27.
' The second assumes XMM, TV display, and mouse and keyboard on pins 8-11. 
' All of the TriBladeProp targets assume the latter.
' 
#ifdef VGA

' TriBladeProp CPU #1 General definitions (no XMM, VGA display, Kbd, Mouse)
'
'    NOTE that LK11 links 5,6,7,8 should be installed, and all LK12 links 
'    should be on 2-3 and should be connected straight through, as shown in
'    the diagram below:
'
'          9  10  11  12  13  14  15  16
'       +-------------------------------+
'     3 | o   o   o   o   o   o   o   o |
'       | |   |   |   |   |   |   |   | |
'     2 | o   o   o   o   o   o   o   o |
'       |                               |
'     1 | o   o   o   o   o   o   o   o |
'       +------------------------------++
'
KBD_PIN   = 26                  ' BASE PIN  (TriBladeProp)
MOUSE_PIN = 24                  ' BASE PIN  (TriBladeProp)
TV_PIN    = -1                  ' BASE PIN  (TriBladeProp)
VGA_PIN   = 8                   ' BASE PIN  (TriBladeProp) 
'
#elseifdef HIRES_VGA
'
' Same as VGA (see above)
'
KBD_PIN   = 26                  ' BASE PIN  (TriBladeProp)
MOUSE_PIN = 24                  ' BASE PIN  (TriBladeProp)
TV_PIN    = -1                  ' BASE PIN  (TriBladeProp)
VGA_PIN   = 8                   ' BASE PIN  (TriBladeProp) 
'
#elseifdef LORES_VGA
'
' Same as VGA (see above)
'
KBD_PIN   = 26                  ' BASE PIN  (TriBladeProp)
MOUSE_PIN = 24                  ' BASE PIN  (TriBladeProp)
TV_PIN    = -1                  ' BASE PIN  (TriBladeProp)
VGA_PIN   = 8                   ' BASE PIN  (TriBladeProp) 
'
#else
'
'
' TriBladeProp CPU #1 General definitions (XMM, TV display, Kbd, Mouse)
'
'    NOTE that no links should be installed on LK11 and that all lk12 links 
'    should be on pins 1-2, but that LINKS 9 & 10, and LINKS 11 & 12 must be 
'    CROSSED OVER - not connected straight - see the diagram below and note 
'    the positions of the 'X' connections:
'
'          9  10  11  12  13  14  15  16
'       +-------------------------------+
'     3 | o   o   o   o   o   o   o   o |
'       |                               |
'     2 | o   o   o   o   o   o   o   o |
'       |   X       X     |   |   |   | |
'     1 | o   o   o   o   o   o   o   o |
'       +------------------------------++
'
KBD_PIN   = 8                    ' BASE PIN  (TriBladeProp)
MOUSE_PIN = 10                   ' BASE PIN  (TriBladeProp)
TV_PIN    = 12                   ' BASE PIN  (TriBladeProp)
VGA_PIN   = -1                   ' BASE PIN  (TriBladeProp)
'
#endif
'
' TriBladeProp CPU #1 General definitions (I2C):
'
I2C_PIN   = 28                  ' I2C Boot EEPROM SCL Pin
I2C_DEV   = $A0                 ' I2C Boot EEPROM Device Address
'
' TriBladeProp CPU #2 General definitions:
'
SD_DO_PIN  = 9                  ' PIN (TriBladeProp)
SD_CLK_PIN = 28                 ' PIN (TriBladeProp) 
SD_DI_PIN  = 8                  ' PIN (TriBladeProp)
SD_CS_PIN  = 14                 ' PIN (TriBladeProp)
'
' TriBladeProp General defintions common to all CPUs:
'
SI_PIN     = 31                 ' PIN (TriBladeProp)
SO_PIN     = 30                 ' PIN (TriBladeProp)
'
' TriBladeProp Clock definitions (all CPUs):
' 
CLOCKMODE = xtal1 + pll16x      ' (TriBladeProp)
XTALFREQ  = 5_000_000           ' (TriBladeProp)
CLOCKFREQ = 80_000_000          ' (TriBladeProp) Nominal clock frequency (required by some drivers)
'
' TriBladeProp InterProp comms definitions:
'
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms
#ifdef CPU_2                 
SIO_LOAD_MODE = %0000           ' SIO Mode used by targets during load loader uses SIO_COMM_MODE
#else 
SIO_LOAD_MODE = %0100           ' SIO Mode used by targets during load loader uses SIO_COMM_MODE
#endif
SIO_COMM_MODE = %0000           ' SIO Mode used by clients and servers for InteProp Comms
#ifdef CPU_2
TX_PIN        = 31              ' Proxy Tx on CPU #2 (for comms to other CPUs)
RX_PIN        = 30              ' Proxy Rx on CPU #2 (for comms to other CPUs)
#else
TX_PIN        = 30              ' Proxy Tx on CPU CPU #1 or CPU #3 (for comms to other CPUs)
RX_PIN        = 31              ' Proxy Tx on CPU CPU #1 or CPU #3 (for comms to other CPUs)
#endif
'
' TriBladeProp XMM Base Address:
'
XMM_BASE_ADDRESS = $0000_0000   ' XMM adddressing from 0
'
' TriBladeProp SPI Base Address:
'
SPI_RW_BASE_ADDRESS  = -1       ' TrBladeProp has no SPI
SPI_RO_BASE_ADDRESS  = -1       ' TrBladeProp has no SPI
'
' TriBladeProp Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' TriBladeProp BlackCat debug pins (SI/SO pins)
'
BLACKCAT_RXPIN = SI_PIN         ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = SO_PIN         ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
'
' TriBladeProp Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' sarted in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve another cog 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by
' an application - it simply is not restarted during the load process 
' (otherwise its values will be lost). Finally, note that this logic
' is replicated for each platform even though it is currently the same
' on all - there may one day be a platform that needs to reserve some
' additional cogs.
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog

#ifdef RESERVE_COG
RESERVED_COG = 6                ' Cog 6 is reserved
LAST_COG     = 4                ' Last cog to be restarted is 4
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 5                ' Last cog to be restarted is 5
#endif

#else

CACHE_COG = -1                  ' XMM Cache driver not loaded

#ifdef RESERVE_COG
RESERVED_COG = 7                ' Cog 6 is reserved
LAST_COG     = 5                ' Last cog to be restarted is 5
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 6                ' Last cog to be restarted is 6
#endif

#endif 


#elseifdef MORPHEUS                  
'===============================================================================
'
' Morpheus General definitions (for CPU #1 and CPU #2):
'
'===============================================================================
KBD_PIN    = 26                 ' BASE PIN  (Morpheus) (CPU #1)
MOUSE_PIN  = 24                 ' BASE PIN  (Morpheus) (CPU #1)
TV_PIN     = -1                 ' Morpheus has no TV out
VGA_PIN    = 16                 ' Morpheus has custom VGA (CPU #2) 
SD_DO_PIN  = 6                  ' (Morpheus) (CPU #1)
SD_CLK_PIN = 5                  ' (Morpheus) (CPU #1)
SD_DI_PIN  = 7                  ' (Morpheus) (CPU #1)
SD_CS_PIN  = 4                  ' (Morpheus) (CPU #1)
I2C_PIN    = 28                 ' I2C Boot EEPROM SCL Pin
I2C_DEV    = $A0                ' I2C Boot EEPROM Device Address
SI_PIN     = 31                 ' PIN (Morpheus)
SO_PIN     = 30                 ' PIN (Morpheus)
'
' Morpheus SPI RAM Support (CPU #1 only)
'
SPI_SO   = 11                 '
SPI_SI   = 10
SPI_CLK  = 9
SPI_CS   = 8
'
'
' Morpheus SPI FLASH Support (CPU #1 only)
'
FLASH_SO   = 15                 '
FLASH_SI   = 14
FLASH_CLK  = 13
FLASH_CS   = 12
'
' Morpheus Clock Definitions (all CPUs):
'
CLOCKMODE = xtal1 + pll16x      ' (Morpheus)
XTALFREQ  = 5_000_000           ' (Morpheus)
CLOCKFREQ = 80_000_000          ' (Morpheus) Nominal clock frequency (required by some drivers)
'
' Morpheus InterProp comms definitions:
'
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms                 
SIO_LOAD_MODE = %0000           ' SIO Mode used by targets during load (loader uses SIO_COMM_MODE)
SIO_COMM_MODE = %0000           ' SIO Mode used by clients and servers for InteProp Comms
#ifdef CPU_1                 
TX_PIN     = 19                 ' Server Tx Pin on CPU #1 (to CPU #2 Pin 31)
RX_PIN     = 18                 ' Server Rx Pin on CPU #1 (to CPU #2 Pin 30)
#else
TX_PIN     = 30                 ' Server Tx Pin on CPU #2 (to CPU #1 Pin 18)
RX_PIN     = 31                 ' Server Rx Pin on CPU #2 (to CPU #1 Pin 19)
#endif
'
' Morpheus XMM Base Address. Catalina currently requires one contiguous block of XMM RAM:
'
XMM_BASE_ADDRESS = $0038_0000   ' We use the shadow RAM address so that the 512Kb on the 
                                ' Morpheus board is contiguous with the RAM on MEM+ - just  
                                ' make sure the address of MEM+ RAM starts at $400000!
                                '
'XMM_BASE_ADDRESS = $0040_0000  ' If you do not have the 512Kb installed on Morpheus, just
                                ' set XMM_BASE to the base of MEM+ RAM (e.g. $400000)  
'
' Morpheus SPI Base Address:
'
SPI_RW_BASE_ADDRESS = $0000_8000 ' SPI Read-Write Base address
SPI_RO_BASE_ADDRESS = $0001_8000 ' SPI Read-Only Base address
'
' Morpheus Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' Morpheus BlackCat debug pins (SI/SO pins)
'
BLACKCAT_RXPIN = SI_PIN         ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = SO_PIN         ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
'
' Morhpeus Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' sarted in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve another cog 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by
' an application - it simply is not restarted during the load process 
' (otherwise its values will be lost). Finally, note that this logic
' is replicated for each platform even though it is currently the same
' on all - there may one day be a platform that needs to reserve some
' additional cogs.
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog

#ifdef RESERVE_COG
RESERVED_COG = 6                ' Cog 6 is reserved
LAST_COG     = 4                ' Last cog to be restarted is 4
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 5                ' Last cog to be restarted is 5
#endif

#else

CACHE_COG = -1                  ' XMM Cache driver not loaded

#ifdef RESERVE_COG
RESERVED_COG = 7                ' Cog 6 is reserved
LAST_COG     = 5                ' Last cog to be restarted is 5
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 6                ' Last cog to be restarted is 6
#endif

#endif 


#elseifdef DEMO
'===============================================================================
'
' Demo Board General definitions:
' 
'===============================================================================
KBD_PIN    = 26                 ' BASE PIN  (Demo)
MOUSE_PIN  = 24                 ' BASE PIN  (Demo)
TV_PIN     = 12                 ' BASE PIN  (Demo)
VGA_PIN    = 16                 ' BASE PIN  (Demo)
SD_DO_PIN  = -1                 ' Demo has no SD Card
SD_CLK_PIN = -1                 ' Demo has no SD Card 
SD_DI_PIN  = -1                 ' Demo has no SD Card
SD_CS_PIN  = -1                 ' Demo has no SD Card
I2C_PIN    = 28                 ' I2C Boot EEPROM SCL Pin
I2C_DEV    = $A0                ' I2C Boot EEPROM Device Address
SI_PIN     = 31                 ' PIN (Demo)
SO_PIN     = 30                 ' PIN (Demo)
'
' Demo Board Clock definitions:
' 
CLOCKMODE = xtal1 + pll16x      ' (Demo)
XTALFREQ  = 5_000_000           ' (Demo)
CLOCKFREQ = 80_000_000          ' (Demo) Nominal clock frequency (required by some drivers)
'
' Demo Board Loader and InterProp Comms definitions:
'
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms                 
SIO_LOAD_MODE = %0000           ' Demo has only one CPU - this is for serial loading
SIO_COMM_MODE = %0000           ' Demo has only one CPU - this is for serial loading
TX_PIN        = -1              ' Demo has only one CPU
RX_PIN        = -1              ' Demo has only one CPU
'
' Demo Board XMM Base Address:
'
XMM_BASE_ADDRESS = -1           ' Demo board has no XMM
'
' Demo Board SPI Base Address:
'
SPI_RW_BASE_ADDRESS  = -1       ' Demo board has no SPI
SPI_RO_BASE_ADDRESS  = -1       ' Demo board has no SPI
'
' Demo Board Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' Demo Board BlackCat debug pins (SI/SO pins)
'
BLACKCAT_RXPIN = SI_PIN         ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = SO_PIN         ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
'
' Demo Board Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' sarted in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve another cog 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by
' an application - it simply is not restarted during the load process 
' (otherwise its values will be lost). Finally, note that this logic
' is replicated for each platform even though it is currently the same
' on all - there may one day be a platform that needs to reserve some
' additional cogs.
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog

#ifdef RESERVE_COG
RESERVED_COG = 6                ' Cog 6 is reserved
LAST_COG     = 4                ' Last cog to be restarted is 4
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 5                ' Last cog to be restarted is 5
#endif

#else

CACHE_COG = -1                  ' XMM Cache driver not loaded

#ifdef RESERVE_COG
RESERVED_COG = 7                ' Cog 6 is reserved
LAST_COG     = 5                ' Last cog to be restarted is 5
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 6                ' Last cog to be restarted is 6
#endif

#endif 


#elseifdef DRACBLADE
'===============================================================================
'
' DracBlade General definitions:
' 
'===============================================================================
KBD_PIN    = 26                 ' BASE PIN  (DracBlade)
MOUSE_PIN  = 24                 ' BASE PIN  (DracBlade)
TV_PIN     = 16                 ' BASE PIN  (DracBlade - if installed)
VGA_PIN    = 16                 ' BASE PIN  (DracBlade - if installed)
SD_DO_PIN  = 12                 ' PIN (DracBlade)
SD_CLK_PIN = 13                 ' PIN (DracBlade) 
SD_DI_PIN  = 14                 ' PIN (DracBlade)
SD_CS_PIN  = 15                 ' PIN (DracBlade)
I2C_PIN    = 28                 ' I2C Boot EEPROM SCL Pin
I2C_DEV    = $A0                ' I2C Boot EEPROM Device Address
SI_PIN     = 31                 ' PIN (DracBlade)
SO_PIN     = 30                 ' PIN (DracBlade)
'
' DracBlade Clock definitions:
' 
CLOCKMODE = xtal1 + pll16x      ' (DracBlade)
XTALFREQ  = 5_000_000           ' (DracBlade)
CLOCKFREQ = 80_000_000          ' (DracBlade) Nominal clock frequency (required by some drivers)
'
' DracBlade Loader and InterProp Comms definitions:
'
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms and serial loading                
SIO_LOAD_MODE = %0000           ' DracBlade has only one CPU - this is for serial loading
SIO_COMM_MODE = %0000           ' DracBlade has only one CPU - this is for serial loading
TX_PIN        = -1              ' DracBlade has only one CPU
RX_PIN        = -1              ' DracBlade has only one CPU
'
' DracBlade XMM Base Address:
'
XMM_BASE_ADDRESS = $0000_0000   ' XMM adddressing from 0
'
' DracBlade SPI Base Address:
'
SPI_RW_BASE_ADDRESS  = -1       ' DracBlade has no SPI
SPI_RO_BASE_ADDRESS  = -1       ' DracBlade has no SPI
'
' DracBlade Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' DracBlade BlackCat debug pins (SI/SO pins)
'
BLACKCAT_RXPIN = SI_PIN         ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = SO_PIN         ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
'
' DracBlade Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' sarted in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve another cog 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by
' an application - it simply is not restarted during the load process 
' (otherwise its values will be lost). Finally, note that this logic
' is replicated for each platform even though it is currently the same
' on all - there may one day be a platform that needs to reserve some
' additional cogs.
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog

#ifdef RESERVE_COG
RESERVED_COG = 6                ' Cog 6 is reserved
LAST_COG     = 4                ' Last cog to be restarted is 4
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 5                ' Last cog to be restarted is 5
#endif

#else

CACHE_COG = -1                  ' XMM Cache driver not loaded

#ifdef RESERVE_COG
RESERVED_COG = 7                ' Cog 6 is reserved
LAST_COG     = 5                ' Last cog to be restarted is 5
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 6                ' Last cog to be restarted is 6
#endif

#endif 


#elseifdef RAMBLADE
'===============================================================================
'
' RamBlade General definitions:
' 
'===============================================================================
KBD_PIN    = 23                 ' BASE PIN  (RamBlade - for "1 pin" KBD driver only)
MOUSE_PIN  = -1                 ' BASE PIN  (RamBlade)
TV_PIN     = 22                 ' BASE PIN  (RamBlade - for "1 pin" TV driver only)
VGA_PIN    = -1                 ' BASE PIN  (RamBlade)
SD_DO_PIN  = 24                 ' PIN (RamBlade)
SD_CLK_PIN = 26                 ' PIN (RamBlade) 
SD_DI_PIN  = 25                 ' PIN (RamBlade)
SD_CS_PIN  = 19                 ' PIN (RamBlade)
I2C_PIN    = 28                 ' I2C Boot EEPROM SCL Pin
I2C_DEV    = $A0                ' I2C Boot EEPROM Device Address
SI_PIN     = 23                 ' PIN (RamBlade)
SO_PIN     = 22                 ' PIN (RamBlade)
'
' RamBlade Clock definitions:
' 
'CLOCKMODE = xtal1 + pll8x       ' (RamBlade)
'XTALFREQ  = 10_000_000          ' (RamBlade)
'CLOCKFREQ = 80_000_000          ' (RamBlade) Nominal clock frequency (required by some drivers)
'
CLOCKMODE = xtal1 + pll16x      ' (RamBlade)
XTALFREQ  = 6_250_000           ' (RamBlade)
CLOCKFREQ = 100_000_000         ' (RamBlade) Nominal clock frequency (required by some drivers)
'
'CLOCKMODE = xtal1 + pll16x      ' (RamBlade)
'XTALFREQ  = 6_500_000           ' (RamBlade)
'CLOCKFREQ = 104_000_000         ' (RamBlade) Nominal clock frequency (required by some drivers)
'
' RamBlade Loader and InterProp Comms definitions:
'
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms and serial loading                
SIO_LOAD_MODE = %0000           ' RamBlade has only one CPU - this is for serial loading
SIO_COMM_MODE = %0000           ' RamBlade has only one CPU - this is for serial loading
TX_PIN        = -1              ' RamBlade has only one CPU
RX_PIN        = -1              ' RamBlade has only one CPU
'
' RamBlade XMM Base Address:
'
XMM_BASE_ADDRESS = $0000_0000   ' XMM adddressing from 0
'
' RamBlade SPI Base Address:
'
SPI_RW_BASE_ADDRESS  = -1       ' RamBlade has no SPI
SPI_RO_BASE_ADDRESS  = -1       ' RamBlade has no SPI
'
' RamBlade Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' RamBlade BlackCat debug pins (SI/SO pins)
'
BLACKCAT_RXPIN = 31             ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = 30             ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
'
' RamBlade Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' sarted in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve another cog 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by
' an application - it simply is not restarted during the load process 
' (otherwise its values will be lost). Finally, note that this logic
' is replicated for each platform even though it is currently the same
' on all - there may one day be a platform that needs to reserve some
' additional cogs.
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog

#ifdef RESERVE_COG
RESERVED_COG = 6                ' Cog 6 is reserved
LAST_COG     = 4                ' Last cog to be restarted is 4
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 5                ' Last cog to be restarted is 5
#endif

#else

CACHE_COG = -1                  ' XMM Cache driver not loaded

#ifdef RESERVE_COG
RESERVED_COG = 7                ' Cog 6 is reserved
LAST_COG     = 5                ' Last cog to be restarted is 5
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 6                ' Last cog to be restarted is 6
#endif

#endif 


#elseifdef ASC
'===============================================================================
'
' Propeller ASC General definitions:
' 
'===============================================================================

KBD_PIN    = 22                 ' BASE PIN (ASC)
MOUSE_PIN  = 20                 ' BASE PIN (ASC)
TV_PIN     = 16                 ' BASE PIN (ASC)
VGA_PIN    = 16                 ' BASE PIN (ASC)
SD_DO_PIN  = 12                 ' PIN (ASC)
SD_CLK_PIN = 13                 ' PIN (ASC) 
SD_DI_PIN  = 11                 ' PIN (ASC)
SD_CS_PIN  = 20                 ' PIN (ASC)
I2C_PIN    = 28                 ' I2C Boot EEPROM SCL Pin
I2C_DEV    = $A0                ' I2C Boot EEPROM Device Address
SI_PIN     = 31                 ' PIN (ASC)
SO_PIN     = 30                 ' PIN (ASC)
'
' Propeller ASC Clock definitions:
' 
CLOCKMODE = xtal1 + pll16x      ' (ASC)
XTALFREQ  = 5_000_000           ' (ASC)
CLOCKFREQ = 80_000_000          ' (ASC) Nominal clock frequency (required by some drivers)
'
' Demo platform Loader and InterProp Comms definitions:
'
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms                 
SIO_LOAD_MODE = %0000           ' ASC has only one CPU - this is for serial loading
SIO_COMM_MODE = %0000           ' ASC has only one CPU - this is for serial loading
TX_PIN        = -1              ' ASC has only one CPU
RX_PIN        = -1              ' ASC has only one CPU
'
' Propeller ASC XMM Base Address:
'
XMM_BASE_ADDRESS = -1           ' ASC board has no XMM
'
' Propeller ASC SPI Base Address:
'
SPI_RW_BASE_ADDRESS  = -1       ' Propeller ASC has no SPI
SPI_RO_BASE_ADDRESS  = -1       ' Propeller ASC has no SPI
'
' Propeller ASC Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' Propeller ASC BlackCat debug pins (SI/SO pins)
'
BLACKCAT_RXPIN = SI_PIN         ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = SO_PIN         ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
'
' Propeller ASC Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' sarted in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve another cog 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by
' an application - it simply is not restarted during the load process 
' (otherwise its values will be lost). Finally, note that this logic
' is replicated for each platform even though it is currently the same
' on all - there may one day be a platform that needs to reserve some
' additional cogs.
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog

#ifdef RESERVE_COG
RESERVED_COG = 6                ' Cog 6 is reserved
LAST_COG     = 4                ' Last cog to be restarted is 4
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 5                ' Last cog to be restarted is 5
#endif

#else

CACHE_COG = -1                  ' XMM Cache driver not loaded

#ifdef RESERVE_COG
RESERVED_COG = 7                ' Cog 6 is reserved
LAST_COG     = 5                ' Last cog to be restarted is 5
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 6                ' Last cog to be restarted is 6
#endif

#endif 


#elseifdef CUSTOM
'
' Comment out the following line when you have configured the Custom platform:
'
ERROR : CUSTOM PLATFORM HAS NOT BEEN CONFIGURED!

'===============================================================================
'
' Custom platform General definitions:
' 
'===============================================================================

KBD_PIN    = -1                 ' BASE PIN  (Custom)
MOUSE_PIN  = -1                 ' BASE PIN  (Custom)
TV_PIN     = -1                 ' BASE PIN  (Custom)
VGA_PIN    = -1                 ' BASE PIN  (Custom)
SD_DO_PIN  = -1                 ' Custom has no SD Card
SD_CLK_PIN = -1                 ' Custom has no SD Card 
SD_DI_PIN  = -1                 ' Custom has no SD Card
SD_CS_PIN  = -1                 ' Custom has no SD Card
I2C_PIN    = 28                 ' I2C Boot EEPROM SCL Pin
I2C_DEV    = $A0                ' I2C Boot EEPROM Device Address
SI_PIN     = 31                 ' PIN (Custom)
SO_PIN     = 30                 ' PIN (Custom)
'
' Custom platform Clock definitions:
' 
CLOCKMODE = xtal1 + pll16x      ' (Custom)
XTALFREQ  = 5_000_000           ' (Custom)
CLOCKFREQ = 80_000_000          ' (Custom) Nominal clock frequency (required by some drivers)
'
' Custom platform Loader and InterProp Comms definitions:
'
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms                 
SIO_LOAD_MODE = %0000           ' Custom has only one CPU - this is for serial loading
SIO_COMM_MODE = %0000           ' Custom has only one CPU - this is for serial loading
TX_PIN        = -1              ' Custom has only one CPU
RX_PIN        = -1              ' Custom has only one CPU
'
' Custom platform XMM Base Address:
'
XMM_BASE_ADDRESS = -1           ' Custom board has no XMM
'
' Custom platform SPI Base Address:
'
SPI_RW_BASE_ADDRESS  = -1       ' Custom platform has no SPI
SPI_RO_BASE_ADDRESS  = -1       ' Custom platform has no SPI
'
' Custom platform Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' Custom platform BlackCat debug pins (SI/SO pins)
'
BLACKCAT_RXPIN = SI_PIN         ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = SO_PIN         ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
'
' Custom platform Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' sarted in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve another cog 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by
' an application - it simply is not restarted during the load process 
' (otherwise its values will be lost). Finally, note that this logic
' is replicated for each platform even though it is currently the same
' on all - there may one day be a platform that needs to reserve some
' additional cogs.
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog

#ifdef RESERVE_COG
RESERVED_COG = 6                ' Cog 6 is reserved
LAST_COG     = 4                ' Last cog to be restarted is 4
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 5                ' Last cog to be restarted is 5
#endif

#else

CACHE_COG = -1                  ' XMM Cache driver not loaded

#ifdef RESERVE_COG
RESERVED_COG = 7                ' Cog 6 is reserved
LAST_COG     = 5                ' Last cog to be restarted is 5
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 6                ' Last cog to be restarted is 6
#endif

#endif 


#else
'===============================================================================
'
' Default General definitions - these are a copy of the Hydra definitions:
'
'===============================================================================
KBD_PIN    = 13                 ' BASE PIN  (Default)
MOUSE_PIN  = 2                  ' PIN GROUP (Default)
TV_PIN     = 24                 ' BASE PIN  (Default)
VGA_PIN    = 16                 ' BASE PIN  (Default)
SD_DO_PIN  = 16                 ' (Default) - note shared with VGA
SD_CLK_PIN = 17                 ' (Default) - note shared with VGA 
SD_DI_PIN  = 18                 ' (Default) - note shared with VGA
SD_CS_PIN  = 19                 ' (Default) - note shared with VGA
I2C_PIN    = 28                 ' I2C Boot EEPROM SCL Pin
I2C_DEV    = $A0                ' I2C Boot EEPROM Device Address
SI_PIN     = 31                 ' PIN (Default)
SO_PIN     = 30                 ' PIN (Default)
'
' Default Clock definitions:
' 
CLOCKMODE = xtal2 + pll8x       ' (Default)
XTALFREQ  = 10_000_000          ' (Default)
CLOCKFREQ = 80_000_000          ' (Default) Nominal clock frequency (required by some drivers)
'
' Default (Loader and InterProp Comms definitions:
'
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms and serial loading                 
SIO_LOAD_MODE = %0000           ' Hydra has only one CPU - this is for serial loading
SIO_COMM_MODE = %0000           ' Hydra has only one CPU - this is for serial loading
TX_PIN        = -1              ' Hydra has only one CPU
RX_PIN        = -1              ' Hydra has only one CPU
'
'Default XMM Base Address:
'
XMM_BASE_ADDRESS = $0000_0000   ' XMM adddressing from 0
'
' Default SPI Base Address:
'
SPI_RW_BASE_ADDRESS  = -1       ' Default has no SPI
SPI_RO_BASE_ADDRESS  = -1       ' Default has no SPI
'
' Default Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' Default BlackCat debug pins (mouse pins) - can be used for LMM or XMM but requires special cable
'
BLACKCAT_RXPIN = 9              ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = 10             ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0010          ' SIO must invert Tx on Hydra when using mouse port
{
'
' Default BlackCat debug pins (SI/SO pins) - can only be used for LMM, but uses normal serial cable
'
BLACKCAT_RXPIN = SI_PIN         ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = SO_PIN         ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
}
'
' Default Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' sarted in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve another cog 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by
' an application - it simply is not restarted during the load process 
' (otherwise its values will be lost). Finally, note that this logic
' is replicated for each platform even though it is currently the same
' on all - there may one day be a platform that needs to reserve some
' additional cogs.
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog

#ifdef RESERVE_COG
RESERVED_COG = 6                ' Cog 6 is reserved
LAST_COG     = 4                ' Last cog to be restarted is 4
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 5                ' Last cog to be restarted is 5
#endif

#else

CACHE_COG = -1                  ' XMM Cache driver not loaded

#ifdef RESERVE_COG
RESERVED_COG = 7                ' Cog 6 is reserved
LAST_COG     = 5                ' Last cog to be restarted is 5
#else
RESERVED_COG = -1               ' No Reserved Cogs
LAST_COG     = 6                ' Last cog to be restarted is 6
#endif

#endif 

#endif

'===============================================================================
'
' Definitions following these lines are common to ALL platforms
'
'===============================================================================

'
' HX512 XMM Constants (for Hybrid or Hydra only, but we define them for all):
'
HX_DBUS_BIT_SHIFT    = 16
HX_CTRL_BIT_SHIFT    = 1
HX_STROBE_BIT_SHIFT  = 30
'
' HX512 commands for controller, pre-shifted to left 1-bit, so we don't have 
' to do it during runtime, small enough to fit in constants
'
HX_CMD_WRITE_SHIFT   = %00000_00_0
HX_CMD_READ_SHIFT    = %00000_01_0
HX_CMD_LOADLO_SHIFT  = %00000_10_0
HX_CMD_LOADHI_SHIFT  = %00000_11_0
'
' HX512 sram commands
'
HX_CMD_WRITE   = %000000_00
HX_CMD_READ    = %000000_01
HX_CMD_LOADLO  = %000000_10
HX_CMD_LOADHI  = %000000_11

'
' For EEPROM modes, the address of the loadable image
'
BOOT_PIN       = 28              ' I2C Boot EEPROM SCL Pin
EEPROM_DEVICE  = $A0             ' I2C EEPROM Device Address
IMAGE_ADDR     = $8000           ' Address of Catalina Program within EEPROM

'
' For TV modes, select PAL_NTSC, INTERLACE
'
#ifdef NTSC
NTSC_PAL = 0                    ' 0 = NTSC                       
#else
NTSC_PAL = 1                    ' 1 = PAL
#endif

#ifdef NO_INTERLACE
INTERLACE = 0                   ' 0 = non-interlace
#else
INTERLACE = 1                   ' 1 = interlace
#endif
'
' Stack size required during SPIN initialization. May need to be increased
' if you add a lot of SPIN initialization code. This has nothing to do with
' the Catalina stack size.
'
STACKSIZE = 50
'
' Plugin types - the Catalina Kernel generally attempts to locate plugins
' by type, not by the cog they happen to be running on. Values up to 12
' are reserved. New plugin types should start from 14 onwards.
'
LMM_VMM = 0       ' main LMM (single threaded)
LMM_HMI = 1       ' HMI Drivers (Kbd/Mouse/Screen)
LMM_LIB = 2       ' Utility library
LMM_FLA = 3       ' Floating Point Library A
LMM_FLB = 4       ' Floating Point Library B
LMM_RTC = 5       ' Real-Time Clock
LMM_FIL = 6       ' File System
LMM_SIO = 7       ' Serial I/O
LMM_DUM = 8       ' Dummy Plugin
LMM_CGI = 9       ' Graphics Plugin
LMM_KBD = 10      ' Keyboard Driver
LMM_SCR = 11      ' Screen Driver
LMM_MOU = 12      ' Mouse Driver
LMM_PRX = 13      ' Proxy Driver
'
#ifdef CACHED
'
' Definitions for XMM CACHE (compatible with jazzed's spisram_cache):
'
#ifdef CACHED_1K
CACHE_BYTES_LOG2       = 10 ' 1024
#elseifdef CACHED_2K
CACHE_BYTES_LOG2       = 11 ' 2048
#elseifdef CACHED_4K
CACHE_BYTES_LOG2       = 12 ' 4096
#else
CACHE_BYTES_LOG2       = 13 ' 8192 (the default)
#endif

CACHE_INDEX_LOG2       = 7 ' log2 of entries in cache index
CACHE_INDEX_MASK       = 1<<CACHE_INDEX_LOG2-1  ' mask for cache index

CACHE_LINE_LOG2        = CACHE_BYTES_LOG2 - CACHE_INDEX_LOG2 ' log2 of size of line
CACHE_LINE_MASK        = 1<<CACHE_LINE_LOG2-1   ' mask for address in cache line

CACHE_CMD_MASK         = %11
' read/write commands
CACHE_WRITE_CMD        = %10
CACHE_READ_CMD         = %11

CACHE_EXTEND_MASK      = %10   ' this bit must be zero for an extended command
' extended commands
CACHE_ERASE_CHIP_CMD   = %000_01
CACHE_ERASE_BLOCK_CMD  = %001_01
CACHE_WRITE_DATA_CMD   = %010_01
CACHE_SD_INIT_CMD      = %011_01
CACHE_SD_READ_CMD      = %100_01
CACHE_SD_WRITE_CMD     = %101_01
'
#endif

'
' Runtime Hub Layout:
'
HUB_SIZE        = $8000
COGSTORE        = HUB_SIZE - 4          ' $7FFC CHECK CogStore.spin & Catalyst_Arguments.spin
XMM_CACHE_RSP   = COGSTORE - 4          ' $7FF8
XMM_CACHE_CMD   = XMM_CACHE_RSP - 4     ' $7FF4
REGISTRY        = XMM_CACHE_CMD - 8*4   ' $7FD4 CHECK registry.e
REQUESTS        = REGISTRY - 8*4*2      ' $7F94 CHECK request_status.e
ARGV_0          = REQUESTS - 24*4       ' $7F34
ARGV_ADDR       = ARGV_0 - 2            ' $7F32
ARGC_ADDR       = ARGV_ADDR - 2         ' $7F30 CHECK catalina_default.s & catalina_debug.s 
DEBUG_FLAG      = ARGC_ADDR - 16        ' $7F20
DEBUG_IN        = DEBUG_FLAG - 4        ' $7F1C
DEBUG_OUT       = DEBUG_IN - 4          ' $7F18
DEBUG_ADDR      = DEBUG_OUT - 4         ' $7F14
DEBUG_BREAK     = DEBUG_ADDR - 4        ' $7F10
FLOAT_XFER      = DEBUG_BREAK - 8       ' $7F08
PROXY_XFER      = FLOAT_XFER - 4        ' $7F04
CGI_DATA        = PROXY_XFER - 4        ' $7F00 CHECK cgi_data.e
'
' Loadtime Hub Layout (note overlap with registry!!!):
'
FLIST_ADDRESS   = XMM_CACHE_CMD - 128*2 ' $7EF4
FLIST_BUFF      = FLIST_ADDRESS - 512   ' $7CF4
FLIST_SIOB      = FLIST_BUFF - 68       ' $7CB4
FLIST_XFER      = FLIST_SIOB - 12       ' $7CA8
FLIST_SECT      = FLIST_XFER - 4        ' $7CA4
FLIST_SHFT      = FLIST_SECT - 4        ' $7CA0
FLIST_FSIZ      = FLIST_SHFT - 4        ' $7C9C
FLIST_PSTK      = FLIST_FSIZ - 4        ' $7C98
FLIST_PREG      = FLIST_PSTK - 4        ' $7C94

'
' Notes on the Registry definitions. 
'
' The Catalina registry provides a place where all plugins can be found, 
' and a request block for sending requests to each plugin. The registry 
' location must be known to all plugins. To use the registry, each plugin 
' finds its own cog number, and then registers by putting its plugin type 
' in the top 8 bits of the long at
'    long[REGISTRY][plugin_cog]
' The bottom 24 bits of that long point to the request block the plugin
' must use to receive requests and return results. A request block of 
' two longs is automatically created for each plugin, but plugins that
' need more are free to allocate their own. However, all request blocks
' must be at least two longs - the first long is the request, which may 
' be a 'short' request (if the request and all its parameters can fit 
' into a single long, or the address of a 'long' parameter block that
' is allocated elsewhere in Hub RAM. Note that all requests are plugin
' specific, and each plugin only typically knows how to interpret its 
' own requests. When complete, the plugin zeroes the first long of the 
' request block, and may either return the result in the second long 
' of the request block (typical for ' short' requests, but also used 
' for some 'long' requests), or in the 'long' parameter block.  
'
' BlackCat Debugger Support (NOTE: these must match the definitions in 
'                            Catalina_blackcat.s)
'
DEBUG_OVERLAY = LMM_INIT_OFF    ' Cog location to overlay debug code
DEBUG_VECTORS = $1eb            ' Cog location to overlay hub vectors (last 5 longs!!!)
DEBUG_MARKER  = LMM_PC_OFF      ' Cog location to write to DEBUG_BREAK at breakpoint                    
BLACKCAT_SIZE = 5 * 4           ' size (in bytes) of Hub RAM communications block for Black Cat
'BLACKCAT_BAUD = 9600            ' Baud Rate for Black Cat comms (RS232 or USB)
'BLACKCAT_BAUD = 57600           ' Baud Rate for Black Cat comms (RS232or USB)
BLACKCAT_BAUD = 115200          ' Baud Rate for Black Cat comms (RS232 or USB)
'BLACKCAT_BAUD = 230400          ' Baud Rate for Black Cat comms (USB)
'BLACKCAT_BAUD = 460800          ' Baud Rate for Black Cat comms (USB)
'BLACKCAT_BAUD = 921600          ' Baud Rate for Black Cat comms (USB)
'
' SD Card Loader definitions. This determines where the cluster list
' of the file to be loaded will be located, and also the maximum size
' of this list. Note that currently, we assume FAT16, which means 
' each entry on the list is 16 bits.
'
' SD Card Buffers and other File Load data used during program load 
' must not overlap the registry. Programs to be loaded must therefore
' be less than FLIST_BUFF in size (i.e. 31kb). If the RESERVE_COG is
' used, this is also the address below which any buffer space must be
' allocated - this us because of the various load mechanisms that may
' be used.  
'
MAX_FLIST_SIZE = (XMM_CACHE_CMD - FLIST_ADDRESS)/2
FLIST_LOG2     = 9              ' LOG (Base 2) of sector size
FLIST_SSIZ     = 1<<FLIST_LOG2  ' size of sector
'
' GRAPHICS Support:
'
X_TILES        = 15             ' Tiles are 16 by 16, so X resolution is 240
Y_TILES        = 10             ' Tiles are 16 by 16, so Y resolution is 160
'                                  
' ARGC/ARGV Support:
'
COGSTORE_MAX   = 300            ' maximum size (LONGS) of CogStore
ARGV_MAX       = 24             ' maximum size (LONGs) of default argv array
'
' CACHE support:
'
#ifdef CACHED
'
' Hub area for CACHED driver:
'
' with 8K CACHE : $5C94
' with 4K CACHE : $6C94
' with 2K CACHE : $7494
' with 1K CACHE : $7894
'
XMM_CACHE       = FLIST_PREG - 1<<CACHE_BYTES_LOG2  
'
' Other equates (with CACHED XMM driver):
'
RUNTIME_ALLOC   = XMM_CACHE   ' can allocate from here down at runtime
LOADTIME_ALLOC  = XMM_CACHE   ' can allocate from here down (loadtime)

#else

'
' Other equates (without CACHED XMM driver):
'
RUNTIME_ALLOC   = CGI_DATA    ' can allocate from here down at runtime
LOADTIME_ALLOC  = FLIST_PREG  ' can allocate from here down (loadtime)

#endif

'
' Kernel Constants. These values are used by the various targets
' and the POD debugger and disassembler as well as by the Kernel.
'
' NOTE : if the Kernel is changed, the values below must also
'        be changed or the debug targets will not work correctly. 
'
LMM_FIRST_REG_OFF = $2b                           
LMM_PC_OFF        = $2b
LMM_SP_OFF        = $2c
LMM_FP_OFF        = $2d
LMM_RI_OFF        = $2e
LMM_BC_OFF        = $2f
LMM_BA_OFF        = $30
LMM_BZ_OFF        = $31
LMM_CS_OFF        = $32
LMM_LAST_REG_OFF  = $4a
'
LMM_INIT_BZ_OFF   = $51
LMM_INIT_PC_OFF   = $52
'
LMM_INIT_OFF      = $53
'
#ifdef SMALL
LMM_1_OFF         = $72         ' for SMALL (XMM) Kernel
#elseifdef LARGE
LMM_1_OFF         = $72         ' for LARGE (XMM) Kernel
#else
LMM_1_OFF         = $67         ' for TINY (LMM) Kernel
LMM_2_OFF         = $6a
LMM_3_OFF         = $6d
LMM_4_OFF         = $70
#endif
'
LMM_FIRST_OPCODE  = $02
LMM_INIT          = $02
LMM_LODL          = $03
LMM_LODA          = $04
LMM_LODF          = $05
LMM_PSHL          = $06
LMM_PSHB          = $07
LMM_CPYB          = $08
LMM_NEWF          = $09
LMM_RETF          = $0a
LMM_CALA          = $0b
LMM_RETN          = $0c
LMM_CALI          = $0d
LMM_JMPA          = $0e
LMM_JMPI          = $0f
LMM_DIVS          = $10
LMM_DIVU          = $11
LMM_MULT          = $12
LMM_BR_Z          = $13
LMM_BRNZ          = $14
LMM_BRAE          = $15
LMM_BR_A          = $16
LMM_BRBE          = $17
LMM_BR_B          = $18
LMM_SYSP          = $19
LMM_PSHA          = $1a
LMM_FADD          = $1b
LMM_FSUB          = $1c
LMM_FMUL          = $1d
LMM_FDIV          = $1e
LMM_FCMP          = $1f
LMM_FLIN          = $20
LMM_INFL          = $21
LMM_PSHM          = $22
LMM_POPM          = $23
LMM_PSHF          = $24
LMM_RLNG          = $25
LMM_RWRD          = $26
LMM_RBYT          = $27
LMM_WLNG          = $28
LMM_WWRD          = $29
LMM_WBYT          = $2a
LMM_LAST_OPCODE   = $2a
'
' Some generally useful constants:
' 
#ifdef PC
HMI_PC  = TRUE
HMI_VGA = FALSE
HMI_TV  = FALSE
#elseifdef VGA
HMI_VGA = TRUE
HMI_PC  = FALSE
HMI_TV  = FALSE
#else
HMI_TV  = TRUE
HMI_PC  = FALSE
HMI_VGA = FALSE
#endif

#ifdef HIRES_VGA
#define HIRES = TRUE
#elseifdef HIRES_TV
#define HIRES = TRUE
#else
#define HIRES = FALSE
#endif
'
PUB InitializeRegistry | i
'
' this routine should be called by the target before it
' starts or initializes any of the plugins to be loaded.
' Note we use the value $FF in the upper byte to mean
' "unknown" or "none"
'
  repeat i from 0 to 7
    long[REGISTRY][i] := REQUESTS + (8*i) + $FF000000
    long[REQUESTS][2 * i] := 0
    long[REQUESTS][2 * i + 1] := 0

PUB Register (cog, plugin_type)
'
' this routine can be used by a plugin to register itself
' with the Catalina Kernel. Plugins must register themselves
' before the Kernel can invoke them or Catalina programs
' can use the functions they provide.
'
  long[REGISTRY][cog] := (plugin_type<<24) + (long[REGISTRY][cog] & $00FFFFFF)

PUB Multiple_Register (cogbits, plugin_type) | i
'
' this routine can be used by a plugin to register multiple
' cogs, based on up to 8 bits set in the cogbits parameter
'
   repeat i from 0 to 7
     if cogbits & 1
        Register(i, plugin_type)
     cogbits >>= 1

PUB UnRegister (cog)
'
' this routine can be used by a plugin to unregister itself
' with the Catalina Kernel. Plugins must unregister themselves
' if they may later be stopped or restarted in a different cog.
' Note we use the value $FF in the upper byte to indicate
' "unknown" or "none"
'
  long[REGISTRY][cog] := (long[REGISTRY][cog] | $FF000000)

PUB SendInitializationData(cog, data_1, data_2)
'
' this routine can be called to send initialization data
' to a cog - note that once initialization is complete,
' SPIN methods such as this cannot be used - requests
' must be done in PASM. Also note that since most
' plugins trigger off the first long of the request,
' it is important to initialize that long second.
'
  long[REQUESTS][2 * cog + 1] := data_2
  long[REQUESTS][2 * cog]     := data_1

PUB WaitForRequest(cog)
  ' wait for a request to be processed
  repeat while long[REQUESTS][2 * cog] <> 0

PUB GetResponse(cog)
  ' get the response of a previous request
  return long[REQUESTS][2 * cog + 1]
 
