{{
'-------------------------------------------------------------------------------
'
' Constants.inc - This file is included by all target files to perform some
'                 logic to set various constant symbols used by the proxy
'                 and HMI plugins. It depends on the following symbols:
'
'                 NO_MOUSE       - do not load/start mouse driver           
'                 NO_KEYBOARD    - do not load/start keyboard driver        
'                 NO_SCREEN      - do not load/start screen driver          
'                 PROXY_KEYBOARD - use a proxy for the keyboard driver      
'                 PROXY_MOUSE    - use a proxy for the mouse driver         
'                 PROXY_SCREEN   - use a proxy for the screen driver        
'                 PROXY_SD       - use a proxy for the SD plugin            
'
'                 It uses these to define the following symbols ...
'
'                 PROXY_SIO    - the SIO plugin is required
'
'                 ... and also to set up the following constants:
'
'                 MODE         - the mode for the SIO plugin
'                 BAUD         - the baud rate for the SIO plugin
'
'                 START_KBD    - start the Keyboard plugin
'                 START_MOUSE  - start the Mouse plugin
'                 START_SCREEN - start the Screen plugin
'
'                 CACHED       - use CACHED XMM driver (8K)
'                 CACHED_1K    - use CACHED XMM driver (1K)
'                 CACHED_2K    - use CACHED XMM driver (2K)
'                 CACHED_4K    - use CACHED XMM driver (4K)
'                 CACHED_8K    - use CACHED XMM driver (8K)
'                 
' This file is included by the following target files:
'
'   lmm_default.spin
'   emm_default.spin
'   smm_default.spin
'   xmm_default.spin
'   lmm_blackcat.spin
'   emm_blackcat.spin
'   smm_blackcat.spin
'   xmm_blackcat.spin
'   Catalina_LMM_Debug.spin
'
' It may also be imported by other files that need these constants set.
'
' Version 2.8 - initial version by Ross Higson
' Version 3.0 - add support for setting CACHED option
' Version 3.0.1 - Allow MOUSE on DRACBLADE
'
}}

' define PROXY_SIO if any of PROXY_SCREEN, PROXY_MOUSE, PROXY_KEYBOARD or PROXY_SD are defined:                 

#ifdef PROXY_SCREEN

#ifndef PROXY_SIO
#define PROXY_SIO
#endif

#elseifdef PROXY_MOUSE

#ifndef PROXY_SIO
#define PROXY_SIO
#endif

#elseifdef PROXY_KEYBOARD

#ifndef PROXY_SIO
#define PROXY_SIO
#endif

#elseifdef PROXY_SD

#ifndef PROXY_SIO
#define PROXY_SIO
#endif

#endif

' set up MODE and BAUD if PROXY_SIO is defined:

#ifdef PROXY_SIO
MODE = Common#SIO_COMM_MODE
BAUD = Common#SIO_BAUD
#endif
'
' Disable MOUSE if both keyboard and mouse are not supported (C3)
'
#ifdef C3
#ifndef NO_MOUSE
#ifndef NO_KEYBOARD
#define NO_MOUSE
#endif
#endif
#endif
'
' Set START_SCREEN, START_KEYBOARD and START_MOUSE. Note that
' simply not starting a HMI drivers saves one or more cogs (which 
' can be useful) but the driver is still loaded - if you need the
' space occupied by the driver for program space (instead of just
' as stack and heap space) you must use a HMI plugin that does not
' load the relevant driver at all.
'
#ifdef NO_SCREEN
START_SCREEN = FALSE
#else
START_SCREEN = TRUE
#endif

#ifdef NO_KEYBOARD
START_KBD    = FALSE
#else
START_KBD    = TRUE
#endif

#ifdef NO_MOUSE
START_MOUSE  = FALSE
#else
START_MOUSE  = TRUE
#endif
'
' Caching options - allow CACHED_2K, CACHED_4K, CACHED_8K or just CACHED
' 
#ifdef CACHED_1K
#ifndef CACHED
#define CACHED
#endif
#elseifdef CACHED_2K
#ifndef CACHED
#define CACHED
#endif
#elseifdef CACHED_4K
#ifndef CACHED
#define CACHED
#endif
#elseifdef CACHED_8K
#ifndef CACHED
#define CACHED
#endif
#endif

