{{
'-------------------------------------------------------------------------------
'
' HMI.inc - This file is included by all target files to perform the logic 
'           required to select the correct HMI option, based on the defined
'           platform (and CPU), as well as the following HMI related symbols:
'
'           GRAPHICS       - load graphics driver instead of screen driver
'   
'           NO_HMI         - do not load any HMI plugin (except GRAPHICS)
'                              
'           NO_MOUSE       - do not load/start mouse driver                          
'           NO_KEYBOARD    - do not load/start keyboard driver                       
'           NO_SCREEN      - do not load/start screen driver                         
'                                                                                    
'           HIRES_VGA      - load a HiRes VGA driver                                 
'           LORES_VGA      - load a LoRes VGA driver                                 
'           VGA            -   "  "   "    "    "                                    
'                                                                                    
'           HIRES_TV       - load a HiRes TV driver                                  
'           LORES_TV       - load a LoRes TV driver                                  
'           TV             -   "  "   "    "    "                                    
'                                                                                    
'           NO_INTERLACE   - use non-interlace mode (TV drivers only)                
'           NTSC           - use NTSC mode (TV drivers only)                         
'                                                                                    
'           PC             - use a PC HMI plugin (screen/kbd only)                   
'           PROPTERMINAL   - use a PropTerminal HMI plugin                           
'                                                                                    
'           PROXY_KEYBOARD - use a proxy for the keyboard driver                     
'           PROXY_MOUSE    - use a proxy for the mouse driver                        
'           PROXY_SCREEN   - use a proxy for the screen driver                       
'
'
' This file is included by the following target files:
'
'   lmm_default.spin
'   emm_default.spin
'   smm_default.spin
'   xmm_default.spin
'   lmm_blackcat.spin
'   emm_blackcat.spin
'   smm_blackcat.spin
'   xmm_blackcat.spin
'   Catalina_LMM_Debug.spin
'   Catalina_Proxy_Server.spin
'   Catalyst_HMI.spin
'
' Version 2.8 - initial version by Ross Higson
' Version 2.9 - Disable mouse by default on C3
' Version 3.0.1 - Allow MOUSE on DRACBLADE
' 
}}                 
'===============================================================================
' Disable MOUSE if both keyboard and mouse are not supported (C3)
'===============================================================================
#ifdef C3
#ifndef NO_MOUSE
#ifndef NO_KEYBOARD
#define NO_MOUSE
#endif
#endif
#endif
'===============================================================================
' Check CPU is correctly specified (multi-CPU platforms only)
'===============================================================================
#ifdef MORPHEUS
#ifdef CPU_1
#define SUPPORT_MORPHEUS_CPU_1
#elseifdef CPU_2
#define SUPPORT_MORPHEUS_CPU_2
#else
  ERROR : CPU NOT SPECIFIED (SPECIFY CPU_1 OR CPU_2) 
#endif
#endif
'
#ifdef TRIBLADEPROP
#ifdef CPU_1
#define SUPPORT_TRIBLADEPROP_CPU_1
#elseifdef CPU_2
#define SUPPORT_TRIBLADEPROP_CPU_2
#elseifdef CPU_3
#define SUPPORT_TRIBLADEPROP_CPU_3
#else
  ERROR : CPU NOT SPECIFIED (SPECIFY CPU_1, CPU_2 OR CPU_3)
#endif
#endif

'===============================================================================
' Check GRAPHICS option is supported on current platform
'===============================================================================
#ifdef GRAPHICS
#ifdef PROXY_SCREEN
  ERROR : GRAPHICS OPTION NOT SUPPORTED WHEN USING PROXY DRIVERS
#elseifdef DRACBLADE
  ERROR : GRAPHICS OPTION NOT SUPPORTED ON THE SPECIFIED PLATFORM
#else  
#define SUPPORT_GRAPHICS_TV
#define START_GRAPHICS
#define NO_SCREEN
#endif
#endif

'===============================================================================
' Check HMI option specified is supported HMI (or NO_HMI specified)
'===============================================================================
#ifdef NO_HMI
'===============================================================================
' The NO_HMI option is supported on all platforms
'===============================================================================
#else
'===============================================================================
' Encode  multiple HMI options into one combined symbol for simplicity
'  (provided the combination is supported)
'===============================================================================
#ifdef SUPPORT_MORPHEUS_CPU_1
'===============================================================================
' MORPHEUS CPU_1 (no VGA or TV HMI options supported)
'===============================================================================
#ifdef HIRES_VGA
#define NOT_SUPPORTED
#elseifdef LORES_VGA
#define NOT_SUPPORTED
#elseifdef VGA
#define NOT_SUPPORTED
#elseifdef HIRES_TV
#define NOT_SUPPORTED
#elseifdef LORES_TV
#define NOT_SUPPORTED
#elseifdef TV
#define NOT_SUPPORTED
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
'
'instead of "SUPPORT_PC" as the default, we define a local keyboard and mouse 
' driver so that we can use proxy drivers - but we disable the screen
'
#ifndef NO_SCREEN
#define NO_SCREEN
#endif
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
'
#endif

#elseifdef SUPPORT_MORPHEUS_CPU_2
'===============================================================================
' MORPHEUS CPU_2 (not TV HMI options, use Morpheus-specific VGA HMI supported)
'===============================================================================
#ifdef HIRES_TV
#define NOT_SUPPORTED
#elseifdef LORES_TV
#define NOT_SUPPORTED
#elseifdef TV
#define NOT_SUPPORTED
#elseifdef HIRES_VGA
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_MORPHEUS_HIRES_VGA_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_MORPHEUS_HIRES_VGA_NO_MOUSE
#endif
#else
#define SUPPORT_MORPHEUS_HIRES_VGA
#endif
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
' default
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_MORPHEUS_HIRES_VGA_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_MORPHEUS_HIRES_VGA_NO_MOUSE
#endif
#else
#define SUPPORT_MORPHEUS_HIRES_VGA
#endif
#endif

#elseifdef SUPPORT_TRIBLADEPROP_CPU_1
'===============================================================================
' TRIBLADEPROP CPU_1 (all HMI options supported)
'===============================================================================
#ifdef HIRES_VGA
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_VGA_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_VGA_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_VGA
#endif
#elseifdef LORES_VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef HIRES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#elseifdef LORES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
' default
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#endif

#elseifdef SUPPORT_TRIBLADEPROP_CPU_2
'===============================================================================
' TRIBLADEPROP CPU_2 (no VGA or TV HMI options supported)
'===============================================================================
#ifdef HIRES_VGA
#define NOT_SUPPORTED
#elseifdef LORES_VGA
#define NOT_SUPPORTED
#elseifdef VGA
#define NOT_SUPPORTED
#elseifdef HIRES_TV
#define NOT_SUPPORTED
#elseifdef LORES_TV
#define NOT_SUPPORTED
#elseifdef TV
#define NOT_SUPPORTED
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
' default
'
'instead of "SUPPORT_PC" as the default, we define a local keyboard and mouse 
' driver so that we can use proxy drivers - but we disable the screen
'
#ifndef NO_SCREEN
#define NO_SCREEN
#endif
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
'
#endif

#elseifdef SUPPORT_TRIBLADEPROP_CPU_3

' TRIBLADEPROP CPU_3 (no VGA or TV HMI options):
#ifdef HIRES_VGA
#define NOT_SUPPORTED
#elseifdef LORES_VGA
#define NOT_SUPPORTED
#elseifdef VGA
#define NOT_SUPPORTED
#elseifdef HIRES_TV
#define NOT_SUPPORTED
#elseifdef LORES_TV
#define NOT_SUPPORTED
#elseifdef TV
#define NOT_SUPPORTED
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
' default
#define SUPPORT_PC
#endif

#elseifdef RAMBLADE

'RAMBLADE (no VGA or TV HMI options):
#ifdef HIRES_VGA
#define NOT_SUPPORTED
#elseifdef LORES_VGA
#define NOT_SUPPORTED
#elseifdef VGA
#define NOT_SUPPORTED
#elseifdef HIRES_TV
#define NOT_SUPPORTED
#elseifdef LORES_TV
#define NOT_SUPPORTED
#elseifdef TV
#define NOT_SUPPORTED
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
' default
#define SUPPORT_PC
#endif

#elseifdef DRACBLADE

'DRACBLADE (no TV HMI options, no mouse):
#ifdef HIRES_TV
#define NOT_SUPPORTED
#elseifdef LORES_TV
#define NOT_SUPPORTED
#elseifdef TV
#define NOT_SUPPORTED
#elseifdef HIRES_VGA
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_VGA_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_VGA_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_VGA
#endif
#elseifdef LORES_VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
' default
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_VGA_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_VGA_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_VGA
#endif
#endif

#elseifdef DEMO
'===============================================================================
'DEMO (all HMI options supported)
'===============================================================================
#ifdef HIRES_VGA
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_VGA_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_VGA_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_VGA
#endif
#elseifdef LORES_VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef HIRES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#elseifdef LORES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
' default
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#endif

#elseifdef CUSTOM
'===============================================================================
'CUSTOM (all HMI options supported)
'===============================================================================
#ifdef HIRES_VGA
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_VGA_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_VGA_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_VGA
#endif
#elseifdef LORES_VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef HIRES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#elseifdef LORES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
' default
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#endif

#elseifdef HYBRID
'===============================================================================
'HYBRID (no VGA HMI options supported)
'===============================================================================
#ifdef HIRES_VGA
#define NOT_SUPPORTED
#elseifdef LORES_VGA
#define NOT_SUPPORTED
#elseifdef VGA
#define NOT_SUPPORTED
#elseifdef HIRES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#elseifdef LORES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
' default
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#endif

#elseifdef HYDRA
'===============================================================================
'HYDRA (all HMI options supported)
'===============================================================================
#ifdef HIRES_VGA
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_VGA_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_VGA_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_VGA
#endif
#elseifdef LORES_VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef HIRES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#elseifdef LORES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
' default
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#endif

#else
'===============================================================================
'DEFAULT (currently default is a copy of HYDRA - i.e. all HMI options supported)
'===============================================================================
#ifdef HIRES_VGA
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_VGA_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_VGA_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_VGA
#endif
#elseifdef LORES_VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef VGA
#ifdef NO_MOUSE
#define SUPPORT_LORES_VGA_NO_MOUSE
#else
#define SUPPORT_LORES_VGA
#endif
#elseifdef HIRES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#elseifdef LORES_TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef TV
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_LORES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_LORES_TV
#endif
#elseifdef PROPTERMINAL
#define SUPPORT_PROPTERMINAL
#elseifdef PC
#define SUPPORT_PC
#else
' default
#ifdef NO_MOUSE
#ifdef NO_KEYBOARD
#define SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
#else
#define SUPPORT_HIRES_TV_NO_MOUSE
#endif
#else
#define SUPPORT_HIRES_TV
#endif
#endif

#endif

#endif

'===============================================================================
' now choose a CGI plugin based on the combined symbol:
'===============================================================================
#ifdef SUPPORT_GRAPHICS_TV
  CGI      : "Catalina_CGI_Plugin_TV"
#endif  
'===============================================================================
' now choose a HMI plugin based on the combined symbol:
'===============================================================================
#ifdef NO_HMI
#elseifdef SUPPORT_MORPHEUS_HIRES_VGA_NO_KEYBOARD_NO_MOUSE
  HMI      : "Catalina_HMI_Plugin_Morpheus_Vga_No_Mouse_No_Keyboard"
#elseifdef SUPPORT_MORPHEUS_HIRES_VGA_NO_MOUSE
  HMI      : "Catalina_HMI_Plugin_Morpheus_Vga_No_Mouse"
#elseifdef SUPPORT_MORPHEUS_HIRES_VGA
  HMI      : "Catalina_HMI_Plugin_Morpheus_Vga"
#elseifdef SUPPORT_HIRES_VGA_NO_KEYBOARD_NO_MOUSE
  HMI      : "Catalina_HMI_Plugin_HiRes_Vga_No_Mouse"
#elseifdef SUPPORT_HIRES_VGA_NO_MOUSE
  HMI      : "Catalina_HMI_Plugin_HiRes_Vga_No_Mouse"
#elseifdef SUPPORT_HIRES_VGA
  HMI      : "Catalina_HMI_Plugin_HiRes_Vga"
#elseifdef SUPPORT_LORES_VGA_NO_MOUSE
  HMI      : "Catalina_HMI_Plugin_LoRes_Vga_No_Mouse"
#elseifdef SUPPORT_LORES_VGA
  HMI      : "Catalina_HMI_Plugin_LoRes_Vga"
#elseifdef SUPPORT_HIRES_TV_NO_KEYBOARD_NO_MOUSE
  HMI      : "Catalina_HMI_Plugin_HiRes_Tv_No_Mouse_No_Keyboard"
#elseifdef SUPPORT_HIRES_TV_NO_MOUSE
  HMI      : "Catalina_HMI_Plugin_HiRes_Tv_No_Mouse"
#elseifdef SUPPORT_HIRES_TV
  HMI      : "Catalina_HMI_Plugin_HiRes_Tv"
#elseifdef SUPPORT_LORES_TV_NO_MOUSE
  HMI      : "Catalina_HMI_Plugin_Tv_No_Mouse"
#elseifdef SUPPORT_LORES_TV_NO_KEYBOARD_NO_MOUSE
  HMI      : "Catalina_HMI_Plugin_Tv_No_Mouse_No_Keyboard"
#elseifdef SUPPORT_LORES_TV
  HMI      : "Catalina_HMI_Plugin_Tv"
#elseifdef SUPPORT_PROPTERMINAL
  HMI      : "Catalina_HMI_Plugin_PropTerminal"
#elseifdef SUPPORT_PC
  HMI      : "Catalina_HMI_Plugin_PC"
#else
  ERROR : HMI OPTION NOT SUPPORTED ON THE SPECIFIED PLATFORM
#endif
'
'===============================================================================
'
' (end of section of code common to all target files)
'
'===============================================================================
